summaryrefslogtreecommitdiffstats
path: root/tdeui/krootpixmap.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
commit13281e2856a2ef43bbab78c5528470309c23aa77 (patch)
tree936bcf8145dc235004c73e9fb3d6b3dca9aa370b /tdeui/krootpixmap.h
parente81c741bb2cf337a43524e75f22f7728ce17a343 (diff)
downloadtdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.tar.gz
tdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'tdeui/krootpixmap.h')
-rw-r--r--tdeui/krootpixmap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/krootpixmap.h b/tdeui/krootpixmap.h
index 8ca135e1f..776863c46 100644
--- a/tdeui/krootpixmap.h
+++ b/tdeui/krootpixmap.h
@@ -159,16 +159,16 @@ public slots:
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically.
*
* @param force Force a tqrepaint, even if the contents did not change.
*/
- void tqrepaint( bool force );
+ void repaint( bool force );
/**
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically. This is equivalent to calling
- * tqrepaint( false ).
+ * repaint( false ).
*/
- void tqrepaint();
+ void repaint();
/**
* Enables custom handling of the background painting. If custom
@@ -159,16 +159,16 @@ public slots:
* as it is handled automatically.
*
- * @param force Force a tqrepaint, even if the contents did not change.
+ * @param force Force a repaint, even if the contents did not change.
*/